==> prestashop_1.4.9.0.zip: prestashop/modules/ogone/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{ogone}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Ihre Bestellung vom';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'ist abgeschlossen.';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Ihre Bestellung wird so schnell wie möglich zugeschickt.';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Bei Fragen oder für weitere Informationen, kontaktieren Sie bitte unseren';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'Kunden-Support';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Wir haben ein Problem bei Ihrer Bestellung festgestellt. Wenn Sie denken, dies sei ein Fehler, können Sie an unseren';
$_MODULE['<{ogone}prestashop>ogone_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Konfiguration aktualisiert';
$_MODULE['<{ogone}prestashop>ogone_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Hilfe';
$_MODULE['<{ogone}prestashop>ogone_879dd0a17cb07d91581b85fa6ade410b'] = 'Ogone ist ein führender europäischer Anbieter von Payment Services mit internationaler Ausrichtung.';
$_MODULE['<{ogone}prestashop>ogone_1e7bcd8050c5264ba8ea688bdb1d999b'] = 'Für mehr als %1$s35.000 Kunden weltweit%2$s übernimmt Ogone die Steuerung und Sicherung des Online-Zahlungsverkehrs. Das Unternehmen mit Hauptsitz in Brüssel bietet dank zertifizierter Schnittstellen zu mehr als %1$s200 Banken und Finanzdienstleistern über 80 internationale, alternative und national populäre Zahlmethoden%2$s in Europa, Asien, Lateinamerika und dem Mittleren Osten an.';
$_MODULE['<{ogone}prestashop>ogone_3936e6f93396b090fa269b25ebcffeac'] = 'Um Ihr Konto zu aktivieren, brauchen Sie einen Vertrag mit einem Akzeptanzpartner. Gerne unterstützen wir Sie dabei!';
$_MODULE['<{ogone}prestashop>ogone_b68664b2bd671c41f46e2ea168895e8a'] = 'Um Ihr kostenloses Testkonto einzurichten, klicken Sie bitte auf nachfolgenden Link:';
$_MODULE['<{ogone}prestashop>ogone_199ab4d0550e412b6dc34cb277a8f4de'] = 'Erstellen Sie ein kostenloses Testkonto';
$_MODULE['<{ogone}prestashop>ogone_a276e4a057c509f54db29bcaabb089ad'] = 'Dieses Testkonto ermöglicht es Ihnen, Ihre eigene PSPID (Ogone Identifikation) zu vergeben , Informationen zu erfragen , die gewünschten Zahlmethoden zu aktivieren und die SHA-in und SHA-out Signaturen zu vergeben, welche für die Konfiguration Ihres Prestashops benötigt werden.';
$_MODULE['<{ogone}prestashop>ogone_5849c2f3cca6a24cb438d8c6614729e0'] = 'Ebenso können Sie Testtransaktionen durchführen.';
$_MODULE['<{ogone}prestashop>ogone_ff1a5bf357135289df7454e19e068b30'] = 'Kopieren Sie Ihr Ogone Testkonto in die Produktivumgebung.';
$_MODULE['<{ogone}prestashop>ogone_263354849869cfad12ab9d6a53c4f629'] = 'Dieser 2. Teil gibt Ihnen die Möglichkeit, Ihre Rechnungsinformationen zu vervollständigen, Ihre Vertragspartner-Nr., die Ihnen Ihr Akzeptanzpartner mitgeteilt hat einzutragen und Ihren Ogone Vertrag zu erhalten.';
$_MODULE['<{ogone}prestashop>ogone_e6cca2e851d66adf3d816520a03f627e'] = 'Aktivieren Sie Ihr Konto bei Prestashop!';
$_MODULE['<{ogone}prestashop>ogone_35af8c5fb7c6f44b6d486698fa913a9e'] = 'Tragen Sie einfach folgende Informationen ein: Ihre PSPID und die SHA-in und SHA-out Signaturen.';
$_MODULE['<{ogone}prestashop>ogone_959006fc1235837e923346d14b6e97f0'] = 'Bei vertrieblichen, technischen oder administrativen Fragen, kontaktieren Sie uns bitte unter 0221-455 30 180.';
$_MODULE['<{ogone}prestashop>ogone_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{ogone}prestashop>ogone_05d749acfbb6a79553aef6a644db881f'] = 'PSPID';
$_MODULE['<{ogone}prestashop>ogone_ac3b5413fdb77e3726a94891c9844b44'] = 'SHA-in Signatur';
$_MODULE['<{ogone}prestashop>ogone_7c287610a5cd0fddf4261f153996da5e'] = 'SHA-out Signatur';
$_MODULE['<{ogone}prestashop>ogone_650be61892bf690026089544abbd9d26'] = 'Modus';
$_MODULE['<{ogone}prestashop>ogone_0cbc6611f5540bd0809a388dc95a615b'] = 'Test';
$_MODULE['<{ogone}prestashop>ogone_756d97bb256b8580d4d71ee0c547804e'] = 'Betrieb';
$_MODULE['<{ogone}prestashop>ogone_b17f3f4dcf653a5776792498a9b44d6a'] = 'Einstellungen aktualisieren';
$_MODULE['<{ogone}prestashop>ogone_75310bf8b7cf2ca4e09332871f98c271'] = 'Bezahlen Sie mit Ogone';
$_MODULE['<{ogone}prestashop>ogone_51e550f8a0e9e127a566c21e9a15538b'] = 'Ogone Logo';
$_MODULE['<{ogone}prestashop>ogone_15ee0c3bac84f0ff0a2af1e6cdc1a048'] = 'Bezahlen Sie sicher und schnell auf der nächsten Seite mit IDEAL / Mastercard / Visa / Paypal / Mister Cash / Bancontact.';
$_MODULE['<{ogone}prestashop>validation_e9f77209121063c8aedd7698f20f4878'] = 'Eingegangene Parameter:';
$_MODULE['<{ogone}prestashop>validation_273e5454628021d87e34051074ac62d1'] = 'Fehlende Parameter:';
$_MODULE['<{ogone}prestashop>validation_cbb285f0e88adea7d492a5b14b9e6d1d'] = 'Fehler (Auth. abgelehnt)';
$_MODULE['<{ogone}prestashop>validation_ee5698e64b5157ad1cbe6aa614288c33'] = 'Zahlung autorisiert / OK';
$_MODULE['<{ogone}prestashop>validation_6b4fcb57371df22836b78f67bc444213'] = 'Unbekannter Status:';
$_MODULE['<{ogone}prestashop>validation_a04830387e55082ed6096ab698ac8238'] = 'Ungültige SHA-1 Signatur';
$_MODULE['<{ogone}prestashop>validation_7eaab6a852dfe4707acde8847dba7ce9'] = 'SHA-1 gegeben:';
$_MODULE['<{ogone}prestashop>validation_8fbed6331a34a844224bfee15145e00f'] = 'SHA-1 berechnet:';
$_MODULE['<{ogone}prestashop>validation_671c1f78cd9a17103c43a10d19157678'] = 'Voller Schlüssel';
$_MODULE['<{ogone}prestashop>waiting_1fe3bb016fa11dd93fb1929f118fd492'] = 'Bitte warten, Ihre Bestellung wird bearbeitet ...';

==> prestashop_1.4.10.0.zip: prestashop/modules/ogone/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{ogone}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Ihre Bestellung vom';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'ist abgeschlossen.';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Ihre Bestellung wird so schnell wie möglich zugeschickt.';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Bei Fragen oder für weitere Informationen, kontaktieren Sie bitte unseren';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'Kunden-Support';
$_MODULE['<{ogone}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Wir haben ein Problem bei Ihrer Bestellung festgestellt. Wenn Sie denken, dies sei ein Fehler, können Sie an unseren';
$_MODULE['<{ogone}prestashop>ogone_40904c61c99a28a3acc110767753fade'] = 'Mit über 80 verschiedenen Zahlungsmethoden und über 200 Akzeptanzpartnern, hilft Ogone Ihnen bei der Verwaltung, dem Collecting und der Sicherung Ihrer Online und Mobile Zahlungen.';
$_MODULE['<{ogone}prestashop>ogone_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Konfiguration aktualisiert';
$_MODULE['<{ogone}prestashop>ogone_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Hilfe';
$_MODULE['<{ogone}prestashop>ogone_879dd0a17cb07d91581b85fa6ade410b'] = 'Ogone ist ein führender europäischer Anbieter von Payment Services mit internationaler Ausrichtung.';
$_MODULE['<{ogone}prestashop>ogone_1e7bcd8050c5264ba8ea688bdb1d999b'] = 'Für mehr als %1$s35.000 Kunden weltweit%2$s übernimmt Ogone die Steuerung und Sicherung des Online-Zahlungsverkehrs. Das Unternehmen mit Hauptsitz in Brüssel bietet dank zertifizierter Schnittstellen zu mehr als %1$s200 Banken und Finanzdienstleistern über 80 internationale, alternative und national populäre Zahlmethoden%2$s in Europa, Asien, Lateinamerika und dem Mittleren Osten an.';
$_MODULE['<{ogone}prestashop>ogone_3936e6f93396b090fa269b25ebcffeac'] = 'Um Ihr Konto zu aktivieren, brauchen Sie einen Vertrag mit einem Akzeptanzpartner. Gerne unterstützen wir Sie dabei!';
$_MODULE['<{ogone}prestashop>ogone_b68664b2bd671c41f46e2ea168895e8a'] = 'Um Ihr kostenloses Testkonto einzurichten, klicken Sie bitte auf nachfolgenden Link:';
$_MODULE['<{ogone}prestashop>ogone_199ab4d0550e412b6dc34cb277a8f4de'] = 'Erstellen Sie ein kostenloses Testkonto';
$_MODULE['<{ogone}prestashop>ogone_a276e4a057c509f54db29bcaabb089ad'] = 'Dieses Testkonto ermöglicht es Ihnen, Ihre eigene PSPID (Ogone Identifikation) zu vergeben , Informationen zu erfragen , die gewünschten Zahlmethoden zu aktivieren und die SHA-in und SHA-out Signaturen zu vergeben, welche für die Konfiguration Ihres Prestashops benötigt werden.';
$_MODULE['<{ogone}prestashop>ogone_5849c2f3cca6a24cb438d8c6614729e0'] = 'Ebenso können Sie Testtransaktionen durchführen.';
$_MODULE['<{ogone}prestashop>ogone_ff1a5bf357135289df7454e19e068b30'] = 'Kopieren Sie Ihr Ogone Testkonto in die Produktivumgebung.';
$_MODULE['<{ogone}prestashop>ogone_263354849869cfad12ab9d6a53c4f629'] = 'Dieser 2. Teil gibt Ihnen die Möglichkeit, Ihre Rechnungsinformationen zu vervollständigen, Ihre Vertragspartner-Nr., die Ihnen Ihr Akzeptanzpartner mitgeteilt hat einzutragen und Ihren Ogone Vertrag zu erhalten.';
$_MODULE['<{ogone}prestashop>ogone_e6cca2e851d66adf3d816520a03f627e'] = 'Aktivieren Sie Ihr Konto bei Prestashop!';
$_MODULE['<{ogone}prestashop>ogone_35af8c5fb7c6f44b6d486698fa913a9e'] = 'Tragen Sie einfach folgende Informationen ein: Ihre PSPID und die SHA-in und SHA-out Signaturen.';
$_MODULE['<{ogone}prestashop>ogone_959006fc1235837e923346d14b6e97f0'] = 'Bei vertrieblichen, technischen oder administrativen Fragen, kontaktieren Sie uns bitte unter 0221-455 30 180.';
$_MODULE['<{ogone}prestashop>ogone_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{ogone}prestashop>ogone_05d749acfbb6a79553aef6a644db881f'] = 'PSPID';
$_MODULE['<{ogone}prestashop>ogone_ac3b5413fdb77e3726a94891c9844b44'] = 'SHA-in Signatur';
$_MODULE['<{ogone}prestashop>ogone_7c287610a5cd0fddf4261f153996da5e'] = 'SHA-out Signatur';
$_MODULE['<{ogone}prestashop>ogone_650be61892bf690026089544abbd9d26'] = 'Modus';
$_MODULE['<{ogone}prestashop>ogone_0cbc6611f5540bd0809a388dc95a615b'] = 'Test';
$_MODULE['<{ogone}prestashop>ogone_756d97bb256b8580d4d71ee0c547804e'] = 'Betrieb';
$_MODULE['<{ogone}prestashop>ogone_b17f3f4dcf653a5776792498a9b44d6a'] = 'Einstellungen aktualisieren';
$_MODULE['<{ogone}prestashop>ogone_48c7c41b72e1d678923ce3571aa65b2d'] = 'Schritt';
$_MODULE['<{ogone}prestashop>ogone_3afbd9828e011526955ca93b48b57524'] = 'Screenshot';
$_MODULE['<{ogone}prestashop>ogone_75310bf8b7cf2ca4e09332871f98c271'] = 'Bezahlen Sie mit Ogone';
$_MODULE['<{ogone}prestashop>ogone_51e550f8a0e9e127a566c21e9a15538b'] = 'Ogone Logo';
$_MODULE['<{ogone}prestashop>ogone_15ee0c3bac84f0ff0a2af1e6cdc1a048'] = 'Bezahlen Sie sicher und schnell auf der nächsten Seite mit IDEAL / Mastercard / Visa / Paypal / Mister Cash / Bancontact.';
$_MODULE['<{ogone}prestashop>validation_e9f77209121063c8aedd7698f20f4878'] = 'Eingegangene Parameter:';
$_MODULE['<{ogone}prestashop>validation_273e5454628021d87e34051074ac62d1'] = 'Fehlende Parameter:';
$_MODULE['<{ogone}prestashop>validation_cbb285f0e88adea7d492a5b14b9e6d1d'] = 'Fehler (Auth. abgelehnt)';
$_MODULE['<{ogone}prestashop>validation_ee5698e64b5157ad1cbe6aa614288c33'] = 'Zahlung autorisiert / OK';
$_MODULE['<{ogone}prestashop>validation_6b4fcb57371df22836b78f67bc444213'] = 'Unbekannter Status:';
$_MODULE['<{ogone}prestashop>validation_a04830387e55082ed6096ab698ac8238'] = 'Ungültige SHA-1 Signatur';
$_MODULE['<{ogone}prestashop>validation_7eaab6a852dfe4707acde8847dba7ce9'] = 'SHA-1 gegeben:';
$_MODULE['<{ogone}prestashop>validation_8fbed6331a34a844224bfee15145e00f'] = 'SHA-1 berechnet:';
$_MODULE['<{ogone}prestashop>validation_671c1f78cd9a17103c43a10d19157678'] = 'Voller Schlüssel';
$_MODULE['<{ogone}prestashop>waiting_1fe3bb016fa11dd93fb1929f118fd492'] = 'Bitte warten, Ihre Bestellung wird bearbeitet ...';
